==> foundation-base-3.2.0.tgz: package/js/foundation.selectTwo.js <==
import $ from 'jquery'
import { Plugin } from 'foundation-sites/js/foundation.core.plugin'

/**
 * SelectTwo module.
 *
 * Called "SelectTwo" to avoid namespace collusions with wrapped "Select2"
 * @module foundation.selectTwo
 */

class SelectTwo extends Plugin {
  /**
   * Creates a new instance.
   * @class
   * @name SelectTwo
   * @fires SelectTwo#init
   * @param {Object} element - A select field as jQuery object.
   * @param {Object} options - Overrides to the default plugin settings.
   */
  _setup (element, options = {}) {
    this.$element = element
    this.className = 'SelectTwo'
    this.options = $.extend(true, {}, SelectTwo.defaults, this.$element.data(), options)
    this._init()
  }

  /**
   * Initializes the plugin and calls functions to get functioning on load.
   * @private
   */
  _init () {
    this.$dropdownWrapper = $('<div class="select-two-dropdown-wrapper"></div>')
    this.$element.after(this.$dropdownWrapper)
    this.$element.select2({
      theme: this.options.theme,
      width: this.options.width,
      minimumResultsForSearch: this.options.minimumResultsForSearch,
      dropdownParent: this.$dropdownWrapper,
      // disable allowClear for now (not needed, not styled yet)
      allowClear: false
    })
    this._events()
  }

  /**
   * Initializes events for SelectTwo.
   *
   * Currently only the `select` event is "wrapped" by this plugin.
   * For all select2 events see https://select2.org/programmatic-control/events
   * @private
   */
  _events () {
    this.$element.off('.selectTwo').on('select2:select', () => {
      this.$element.trigger('select.zf.selectTwo')
    })
    // Workaround for incompatibility of select2 with jQuery 3.6's nested-focus fix.
    // See https://github.com/select2/select2/issues/5993
    this.$element.on('select2:open', (e) => {
      // Set focus on search field.
      e.target.parentNode.querySelector('.select2-search__field').focus()
    })
    // Workaround for select2 not triggering native JS events.
    // See https://github.com/select2/select2/issues/1908
    const changeEvent = new Event('change')
    this.$element.on('change.select2', (e) => {
      if (!e.originalEvent) {
        e.stopImmediatePropagation()
        e.target.dispatchEvent(changeEvent)
      }
    })
  }

  /**
   * Destroys an instance of SelectTwo.
   */
  _destroy () {
    this.$element.select2('destroy')
    this.$element.off('select2:select')
    this.$dropdownWrapper.remove()
  }
}

/**
 * Default settings for plugin
 */
SelectTwo.defaults = {
  /**
   * The default theme to set.
   * @option
   * @type {string}
   * @default 'foundation'
   */
  theme: 'foundation',

  /**
   * The default container width to set.
   * https://select2.org/appearance#container-width
   * @option
   * @type {string|null}
   * @default null
   */
  width: null, // null inhibits setting a `width` via the style attribute

  /**
   * The minimum number of results required to display a search box.
   * https://select2.org/searching#limiting-display-of-the-search-box-to-large-result-sets
   * @option
   * @type {number}
   * @default 5
   */
  minimumResultsForSearch: 5
}

export { SelectTwo }

==> foundation-base-3.3.5.tgz: package/js/foundation.selectTwo.js <==
import $ from 'jquery'
import { Plugin } from 'foundation-sites/js/foundation.core.plugin'

/**
 * SelectTwo module.
 *
 * Called "SelectTwo" to avoid namespace collusions with wrapped "Select2"
 * @module foundation.selectTwo
 */

class SelectTwo extends Plugin {
  /**
   * Creates a new instance.
   * @class
   * @name SelectTwo
   * @fires SelectTwo#init
   * @param {Object} element - A select field as jQuery object.
   * @param {Object} options - Overrides to the default plugin settings.
   */
  _setup (element, options = {}) {
    this.$element = element
    this.className = 'SelectTwo'
    this.options = $.extend(true, {}, SelectTwo.defaults, this.$element.data(), options)
    this._init()
  }

  /**
   * Initializes the plugin and calls functions to get functioning on load.
   * @private
   */
  _init () {
    this.$dropdownWrapper = $('<div class="select-two-dropdown-wrapper"></div>')
    this.$element.after(this.$dropdownWrapper)
    this.$element.select2({
      theme: this.options.theme,
      width: this.options.width,
      minimumResultsForSearch: this.options.minimumResultsForSearch,
      dropdownParent: this.$dropdownWrapper,
      // disable allowClear for now (not needed, not styled yet)
      allowClear: false
    })
    this._events()
  }

  /**
   * Initializes events for SelectTwo.
   *
   * Currently only the `select` event is "wrapped" by this plugin.
   * For all select2 events see https://select2.org/programmatic-control/events
   * @private
   */
  _events () {
    this.$element.off('.selectTwo').on('select2:select', () => {
      this.$element.trigger('select.zf.selectTwo')
    })
    // Workaround for incompatibility of select2 with jQuery 3.6's nested-focus fix.
    // See https://github.com/select2/select2/issues/5993
    this.$element.on('select2:open', (e) => {
      // Set focus on search field.
      e.target.parentNode.querySelector('.select2-search__field').focus()
    })
    // Workaround for select2 not triggering native JS events.
    // See https://github.com/select2/select2/issues/1908
    const changeEvent = new Event('change', { bubbles: true })
    this.$element.on('change.select2', (e) => {
      if (!e.originalEvent) {
        e.stopImmediatePropagation()
        e.target.dispatchEvent(changeEvent)
      }
    })
  }

  /**
   * Destroys an instance of SelectTwo.
   */
  _destroy () {
    this.$element.select2('destroy')
    this.$element.off('select2:select')
    this.$dropdownWrapper.remove()
  }
}

/**
 * Default settings for plugin
 */
SelectTwo.defaults = {
  /**
   * The default theme to set.
   * @option
   * @type {string}
   * @default 'foundation'
   */
  theme: 'foundation',

  /**
   * The default container width to set.
   * https://select2.org/appearance#container-width
   * @option
   * @type {string|null}
   * @default null
   */
  width: null, // null inhibits setting a `width` via the style attribute

  /**
   * The minimum number of results required to display a search box.
   * https://select2.org/searching#limiting-display-of-the-search-box-to-large-result-sets
   * @option
   * @type {number}
   * @default 5
   */
  minimumResultsForSearch: 5
}

export { SelectTwo }
